@@ -7,7 +7,7 @@ use rayon::ThreadPool;
 use rayon::ThreadPoolBuilder;
 use robotparser_fork::RobotFileParser;
 use hashbrown::HashSet;
-use std::{sync, time::{Duration}};
+use std::{time::{Duration}};
 use std::sync::mpsc::{channel, Sender, Receiver};
 use reqwest::header::CONNECTION;
 use reqwest::header;
